notetools.NoteHead
==================

.. abjad-lineage:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead

.. autoclass:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.named_chromatic_pitch
   :noindex:

.. autoattribute:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.storage_format
   :noindex:

.. autoattribute:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.tweak
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.is_cautionary
   :noindex:

.. autoattribute:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.is_forced
   :noindex:

.. autoattribute:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.written_pitch
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.__eq__
   :noindex:

.. automethod:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.__ge__
   :noindex:

.. automethod:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.__gt__
   :noindex:

.. automethod:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.__le__
   :noindex:

.. automethod:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.__lt__
   :noindex:

.. automethod:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.__ne__
   :noindex:

.. automethod:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.__repr__
   :noindex:

.. automethod:: abjad.tools.notetools.NoteHead.NoteHead.NoteHead.__str__
   :noindex:
